@@ -1,11 +1,23 @@
 from typing import Optional
 
 
+class UnknownFileFormat(Exception):
+    """
+    The file format could not be automatically detected
+    """
+
+
 class FileFormatError(Exception):
     """
     The file is not formatted correctly
+
+    Attributes:
+        line: If available, the number of the line at which the error occurred
+          or None if not.
+          The first line has index 0.
     """
-    format = 'sequence'  # Something generic that works for both FASTA and FASTQ
+
+    format = "sequence"  # Something generic that works for both FASTA and FASTQ
 
     def __init__(self, msg: str, line: Optional[int]):
         super().__init__(msg, line)
@@ -21,6 +33,7 @@ class FastqFormatError(FileFormatError):
     """
     The FASTQ file is not formatted correctly
     """
+
     format = "FASTQ"
 
 
@@ -28,10 +41,5 @@ class FastaFormatError(FileFormatError):
     """
     The FASTA file is not formatted correctly
     """
+
     format = "FASTA"
-
-
-class UnknownFileFormat(Exception):
-    """
-    The file format could not be automatically detected
-    """
