@@ -2,18 +2,18 @@ import os
 from typing import Optional, Union, BinaryIO, Tuple
 
 from .exceptions import UnknownFileFormat
-from .readers import FastaReader, FastqReader
+from .readers import BamReader, FastaReader, FastqReader
 from .writers import FastaWriter, FastqWriter
 
 
-def _open_single(
+def _open_single(  # noqa: C901
     file_or_path: Union[str, os.PathLike, BinaryIO],
     opener,
     *,
     fileformat: Optional[str] = None,
     mode: str = "r",
     qualities: Optional[bool] = None,
-) -> Union[FastaReader, FastaWriter, FastqReader, FastqWriter]:
+) -> Union[BamReader, FastaReader, FastaWriter, FastqReader, FastqWriter]:
     """
     Open a single sequence file.
     """
@@ -59,7 +59,16 @@ def _open_single(
         if "r" in mode:
             return FastqReader(file, _close_file=close_file)
         return FastqWriter(file, _close_file=close_file)
-
+    elif fileformat == "bam":
+        if "r" in mode:
+            return BamReader(file, _close_file=close_file)
+        # This should not be reached
+        raise NotImplementedError("Only reading is supported for BAM files")
+    elif fileformat == "bam_no_header":
+        if "r" in mode:
+            return BamReader(file, _close_file=close_file, with_header=False)
+        # This should not be reached
+        raise NotImplementedError("Only reading is supported for headerless BAM files")
     if close_file:
         file.close()
     raise UnknownFileFormat(
@@ -108,6 +117,8 @@ def _detect_format_from_name(name: str) -> Optional[str]:
         return "fasta"
     elif ext in [".fastq", ".fq"] or (ext == ".txt" and name.endswith("_sequence")):
         return "fastq"
+    elif ext == "bam":
+        return "bam"
     return None
 
 
@@ -115,17 +126,19 @@ def _detect_format_from_content(file: BinaryIO) -> Optional[str]:
     """
     Return 'fasta', 'fastq' or None
     """
-    if file.seekable():
-        original_position = file.tell()
-        first_char = file.read(1)
-        file.seek(original_position)
+    if hasattr(file, "peek"):
+        magic = file.peek(4)[0:4]
     else:
         # We cannot always use peek() because BytesIO objects do not suppert it
-        first_char = file.peek(1)[0:1]  # type: ignore
-    formats = {
-        b"@": "fastq",
-        b">": "fasta",
-        b"#": "fasta",  # Some FASTA variants allow comments
-        b"": "fastq",  # Pretend FASTQ for empty input
-    }
-    return formats.get(first_char, None)
+        original_position = file.tell()
+        magic = file.read(4)
+        file.seek(original_position)
+    if magic.startswith(b"@") or magic == b"":
+        # Pretend FASTQ for empty input
+        return "fastq"
+    elif magic.startswith(b">") or magic.startswith(b"#"):
+        # Some FASTA variants allow comments
+        return "fasta"
+    elif magic == b"BAM\1":
+        return "bam"
+    return None
